pyhsm.basic_cmd.YHSM_Cmd_Echo

Package pyhsm :: Module basic_cmd :: Class YHSM_Cmd_Echo |
[frames] | no frames]

# Class YHSM_Cmd_Echo

    cmd.YHSM_Cmd --+
                   |
                  YHSM_Cmd_Echo

Send something to the stick, and expect to get it echoed back.

Instance Methods
__init__(self, stick, payload=`'````'`) The base class for all YSM_ commands. |
parse_result(self, data) This function is intended to be overridden by sub-classes that implements commands that should not just return the data read from the YubiHSM. |
Inherited from `cmd.YHSM_Cmd`: `execute`

Class Variables
Inherited from `cmd.YHSM_Cmd`: `executed`, `response_status`

Method Details

### __init__(self, stick, payload=`'````'`) (Constructor) |
The base class for all YSM_ commands. Parameters: `stick` - Reference to a YubiHSM `command` - The YSM_xxx command defined in pyhsm.defines. `payload` - a packed C struct, represented as a Python string Overrides: cmd.YHSM_Cmd.__init__ (inherited documentation)

### parse_result(self, data) |
This function is intended to be overridden by sub-classes that implements commands that should not just return the data read from the YubiHSM. Overrides: cmd.YHSM_Cmd.parse_result (inherited documentation)